@@ -31,15 +31,13 @@ pub fn scripted_fixture_repo_read_only_with_args(
     let script_identity = map
         .entry(args.iter().fold(script_path.clone(), |p, a| p.join(a)))
         .or_insert_with(|| {
-            let mut crc_value = crc::crc32::update(
-                0,
-                &crc::crc32::IEEE_TABLE,
-                &std::fs::read(&script_path).expect("file can be read entirely"),
-            );
+            let crc_value = crc::Crc::<u32>::new(&crc::CRC_32_CKSUM);
+            let mut crc_digest = crc_value.digest();
+            crc_digest.update(&std::fs::read(&script_path).expect("file can be read entirely"));
             for arg in args.iter() {
-                crc_value = crc::crc32::update(crc_value, &crc::crc32::IEEE_TABLE, arg.as_bytes());
+                crc_digest.update(arg.as_bytes());
             }
-            crc_value
+            crc_digest.finalize()
         })
         .to_owned();
     let script_result_directory = fixture_path(
